pub fn initialize_tempo_precompiles(
db: &mut dyn Db,
chain_id: u64,
timestamp: u64,
test_accounts: &[Address],
hardfork: TempoHardfork,
) -> Result<(), TempoPrecompileError>Expand description
Initialize Tempo precompiles and fee tokens for Anvil.
This sets up the same precompiles and tokens as Tempo’s genesis, enabling proper fee token validation for transactions.
Additionally, mints fee tokens to the provided test accounts so they can send transactions in Tempo mode.